/* Text clustering method, SKWIC algorithm implementation
 * Model class used to store a document
 * Authors: Roman Milos, Vladimir Bartik, May 2011
 */
package dip.model;

import java.io.File;
import java.util.Collection;
import java.util.HashMap;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;

/**
 * A class used to store a document from the collection of documents. 
 * @author Roman
 */
@XmlAccessorType(XmlAccessType.NONE)
public class Dokument {
   
    @XmlElement
    private String jmeno;
    @XmlElement
    private File soubor;
    @XmlElementWrapper(name = "termy")
    @XmlElement(name="term")
    private Collection<Slovo> slovaKolekce;
    private HashMap<String, Slovo> slova;
    @XmlElement
    private String title;
    @XmlElement
    private String kategorie;
    private String text;
    
    /**
     * Returns the category of current document.
     * @return category in a form of string
     */
    public String getKategorie() {
        return kategorie;
    }
    
    /**
     * Sets the category of current document.
     * @param kategorie category name
     */
    public void setKategorie(String kategorie) {
        this.kategorie = kategorie;
    }

    /**
     * Conversion of a hash map into collection - preparation to export. 
     */
    public void pripravNaExport() {
        slovaKolekce = slova.values();

    }

    /**
     * Conversion of a collection into a hash map - done after import.
     */
    public void opravPoImportu() {
        slova.clear();
       if (slovaKolekce!=null) {
            
            for (Slovo s : slovaKolekce) {
                slova.put(s.getJmeno(), s);
            }
        }
    }

    /**
     * Constructor with initialization.
     */
    public Dokument() {
        this.slova = new HashMap<String, Slovo>(50);
    }

    /**
     * Gets the text content of the document. 
     * @return contents in a form of string
     */  
    public String getText() {
        return text;
    }
    
    /**
     * Sets the text content of the document. 
     * @param text document contents in a form of string
     */  
    public void setText(String text) {
        this.text = text;
    }

    /**
     * Gets the name of the document. 
     * @return the name in a form of string
     */      
    public String getJmeno() {
        return jmeno;
    }
    
    /**
     * Sets the name of the document. 
     * @param jmeno name in a form of string
     */ 
    public void setJmeno(String jmeno) {
        this.jmeno = jmeno;
    }
    
    /**
     * Gets the set of words contained in the document.
     * @return a set of words in a form of hash map
     */  
    public HashMap<String, Slovo> getSlova() {
        return slova;
    }
    
    /**
     * Sets the hash map contents of words contained in the document.
     * @param slova hash map of words
     */  
    public void setSlova(HashMap<String, Slovo> slova) {
        this.slova = slova;
    }
    
    /**
     * Gets the file, which contains the document. 
     * @return a file with the document
     */  
    public File getSoubor() {
        return soubor;
    }
    
    /**
     * Sets the file, which contains the document. 
     * @param soubor a file with the document contents
     */ 
    public void setSoubor(File soubor) {
        this.soubor = soubor;
    }
    
    /**
     * Gets the title of the document. 
     * @return title of the document in a form of string
     */  
    public String getTitle() {
        return title;
    }
    
    /**
     * Sets the title of the document. 
     * @param title of the document
     */ 
    public void setTitle(String title) {
        this.title = title;
    }
}
