/* Text clustering method, SKWIC algorithm implementation
 * Model class responsible for global storing of terms
 * Authors: Roman Milos, Vladimir Bartik, May 2011
 */
package dip.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;

/**
 * Model class responsible for global storing of terms (extends the Slovo class)
 *
 * @author Roman
 */
@XmlAccessorType(XmlAccessType.NONE)
public class SlovoSuma extends Slovo {
//number of documents containig this word
    @XmlElement
    private int pocetDokumentu = 1;
    //Maximum frequence of this term in one document
    @XmlElement
    private int maximalniVyskyty = 1;
    //Document with the last occurrence of this term 
    private Dokument dokument = null;
    
    /**
     * Gets the document.
     * @return a document
     */
    public Dokument getDokument() {
        return dokument;
    }
    
    /**
     * Gets the value of maximum occurrence of a term in a document.
     * @return maximum occurrence value
     */
    public int getMaximalniVyskyty() {
        return maximalniVyskyty;
    }
    
    /**
     * Sets the value of maximum occurrence of a term in a document.
     * @param maximalniVyskyty maximum occurrence value
     */
    public void setMaximalniVyskyty(int maximalniVyskyty) {
        this.maximalniVyskyty = maximalniVyskyty;
    }
    
    /**
     * Sets the document.
     * @param dokument a document
     */
    public void setDokument(Dokument dokument) {
        this.dokument = dokument;
    }
    
    /**
     * Constructor including creation of Slovo class instance.
     * @param jmeno name of the word
     */
    public SlovoSuma(String jmeno) {
        super(jmeno);
    }
    
    /**
     * Constructor
     */
    public SlovoSuma() {
    }
    
    /**
     * Gets the value of count of documents containing this term.
     * @return count of documents
     */
    public int getPocetDokumentu() {
        return pocetDokumentu;
    }
    
    /**
     * Sets the value of count of documents containing this term.
     * @param pocetDokumentu count of documents
     */
    public void setPocetDokumentu(int pocetDokumentu) {
        this.pocetDokumentu = pocetDokumentu;
    }

    /**
     * Increments count of documents containing this term.
     * @param d a document
     */
    public void incDokument(Dokument d) {
        pocetDokumentu++;
    }
}
